@@ -803,7 +803,7 @@ void HandleKey(Key key, int key_status)
 
   if (HandleGadgetsKeyInput(key))
   {
-    if (key != KSYM_Escape)	/* always allow ESC key to be handled */
+    if (key != KSYM_BackSpace)	/* always allow ESC key to be handled */
       key = KSYM_UNDEFINED;
   }
 
@@ -837,7 +837,7 @@ void HandleKey(Key key, int key_status)
 	    HandleHallOfFame(0, 0, 0, 0, MB_MENU_CHOICE);
 	  break;
 
-	case KSYM_Escape:
+	case KSYM_BackSpace:
 	  if (game_status != GAME_MODE_MAIN)
 	    FadeSkipNextFadeIn();
 
@@ -893,7 +893,7 @@ void HandleKey(Key key, int key_status)
       break;
 
     case GAME_MODE_EDITOR:
-      if (!anyTextGadgetActiveOrJustFinished || key == KSYM_Escape)
+      if (!anyTextGadgetActiveOrJustFinished || key == KSYM_BackSpace)
 	HandleLevelEditorKeyInput(key);
       break;
 
@@ -901,7 +901,7 @@ void HandleKey(Key key, int key_status)
     {
       switch (key)
       {
-        case KSYM_Escape:
+        case KSYM_BackSpace:
 	  RequestQuitGame(setup.ask_on_escape);
 	  break;
 
@@ -997,7 +997,7 @@ void HandleKey(Key key, int key_status)
     }
 
     default:
-      if (key == KSYM_Escape)
+      if (key == KSYM_BackSpace)
       {
 	game_status = GAME_MODE_MAIN;
 	DrawMainMenu();
